const path = require('path');
const webpack = require('webpack');
const ExtractTextPlugin = require('extract-text-webpack-plugin');
const styles = new ExtractTextPlugin('./autocomplete.css');

module.exports = {
    entry: [
        path.resolve(__dirname, './src/components/Autocomplete.jsx')
    ],


    output: {
        path: __dirname + '/dist',
        publicPath: '/',
        filename: './index.js',
        libraryTarget: 'commonjs2'
    },

    devtool: 'source-maps',

    module: {
        rules: [
            {test: /\.jsx?$/, exclude: /node_modules/, use: ['babel-loader']},
            {
                test: /\.scss$|\.css$/,
                exclude: path.resolve(__dirname, './styles/App.scss'),
                use: styles.extract({
                    use: ['css-loader', 'sass-loader']
                })
            },
            {test: /\.(jpe?g|png|gif|svg|xml)$/i, use: ['file-loader?name=images/[name].[ext]']},
            {test: /\.(ttf|eot|svg|woff2?)(\?v=[0-9]\.[0-9]\.[0-9])?$/, use: ['file-loader?name=fonts/[name].[ext]']},
        ]
    },

    devServer: {
        hot: true,
        contentBase: './',
        port: 3000
    },

    plugins: [
        new webpack.optimize.AggressiveMergingPlugin(),//Merge chunks
        styles
    ],
};
